@@ -18,24 +18,24 @@
 
 # Map enum member names to fully scoped names.
 EnumMap = {
-    'Qt::AlignHCenter':         'Qt::Alignment::AlignHCenter',
-    'Qt::AlignJustify':         'Qt::Alignment::AlignJustify',
-    'Qt::AlignLeft':            'Qt::Alignment::AlignLeft',
-    'Qt::AlignRight':           'Qt::Alignment::AlignRight',
+    'Qt::AlignHCenter':         'Qt::AlignmentFlag::AlignHCenter',
+    'Qt::AlignJustify':         'Qt::AlignmentFlag::AlignJustify',
+    'Qt::AlignLeft':            'Qt::AlignmentFlag::AlignLeft',
+    'Qt::AlignRight':           'Qt::AlignmentFlag::AlignRight',
 
-    'Qt::AlignBaseline':        'Qt::Alignment::AlignBaseline',
-    'Qt::AlignBottom':          'Qt::Alignment::AlignBottom',
-    'Qt::AlignTop':             'Qt::Alignment::AlignTop',
-    'Qt::AlignVCenter':         'Qt::Alignment::AlignVCenter',
+    'Qt::AlignBaseline':        'Qt::AlignmentFlag::AlignBaseline',
+    'Qt::AlignBottom':          'Qt::AlignmentFlag::AlignBottom',
+    'Qt::AlignTop':             'Qt::AlignmentFlag::AlignTop',
+    'Qt::AlignVCenter':         'Qt::AlignmentFlag::AlignVCenter',
 
-    'Qt::AlignAbsolute':        'Qt::Alignment::AlignAbsolute',
-    'Qt::AlignLeading':         'Qt::Alignment::AlignLeading',
-    'Qt::AlignTrailing':        'Qt::Alignment::AlignTrailing',
+    'Qt::AlignAbsolute':        'Qt::AlignmentFlag::AlignAbsolute',
+    'Qt::AlignLeading':         'Qt::AlignmentFlag::AlignLeading',
+    'Qt::AlignTrailing':        'Qt::AlignmentFlag::AlignTrailing',
 
-    'Qt::AlignCenter':          'Qt::Alignment::AlignCenter',
+    'Qt::AlignCenter':          'Qt::AlignmentFlag::AlignCenter',
 
-    'Qt::AlignHorizontal_Mask': 'Qt::Alignment::AlignHorizontal_Mask',
-    'Qt::AlignVertical_Mask':   'Qt::Alignment::AlignVertical_Mask',
+    'Qt::AlignHorizontal_Mask': 'Qt::AlignmentFlag::AlignHorizontal_Mask',
+    'Qt::AlignVertical_Mask':   'Qt::AlignmentFlag::AlignVertical_Mask',
 
     'Qt::DownArrow':    'Qt::ArrowType::DownArrow',
     'Qt::LeftArrow':    'Qt::ArrowType::LeftArrow',
@@ -64,19 +64,19 @@ EnumMap = {
     'Qt::Saturday':     'Qt::DayOfWeek::Saturday',
     'Qt::Sunday':       'Qt::DayOfWeek::Sunday',
 
-    'Qt::AllDockWidgetAreas':   'Qt::DockWidgetAreas::AllDockWidgetAreas',
-    'Qt::LeftDockWidgetArea':   'Qt::DockWidgetAreas::LeftDockWidgetArea',
-    'Qt::RightDockWidgetArea':  'Qt::DockWidgetAreas::RightDockWidgetArea',
-    'Qt::TopDockWidgetArea':    'Qt::DockWidgetAreas::TopDockWidgetArea',
-    'Qt::BottomDockWidgetArea': 'Qt::DockWidgetAreas::BottomDockWidgetArea',
-    'Qt::NoDockWidgetArea':     'Qt::DockWidgetAreas::NoDockWidgetArea',
+    'Qt::AllDockWidgetAreas':   'Qt::DockWidgetArea::AllDockWidgetAreas',
+    'Qt::LeftDockWidgetArea':   'Qt::DockWidgetArea::LeftDockWidgetArea',
+    'Qt::RightDockWidgetArea':  'Qt::DockWidgetArea::RightDockWidgetArea',
+    'Qt::TopDockWidgetArea':    'Qt::DockWidgetArea::TopDockWidgetArea',
+    'Qt::BottomDockWidgetArea': 'Qt::DockWidgetArea::BottomDockWidgetArea',
+    'Qt::NoDockWidgetArea':     'Qt::DockWidgetArea::NoDockWidgetArea',
 
-    'Qt::ActionMask':       'Qt::DropActions::ActionMask',
-    'Qt::CopyAction':       'Qt::DropActions::CopyAction',
-    'Qt::IgnoreAction':     'Qt::DropActions::IgnoreAction',
-    'Qt::LinkAction':       'Qt::DropActions::LinkAction',
-    'Qt::MoveAction':       'Qt::DropActions::MoveAction',
-    'Qt::TargetMoveAction': 'Qt::DropActions::TargetMoveAction',
+    'Qt::ActionMask':       'Qt::DropAction::ActionMask',
+    'Qt::CopyAction':       'Qt::DropAction::CopyAction',
+    'Qt::IgnoreAction':     'Qt::DropAction::IgnoreAction',
+    'Qt::LinkAction':       'Qt::DropAction::LinkAction',
+    'Qt::MoveAction':       'Qt::DropAction::MoveAction',
+    'Qt::TargetMoveAction': 'Qt::DropAction::TargetMoveAction',
 
     'Qt::ClickFocus':   'Qt::FocusPolicy::ClickFocus',
     'Qt::NoFocus':      'Qt::FocusPolicy::NoFocus',
@@ -84,40 +84,40 @@ EnumMap = {
     'Qt::StrongFocus':  'Qt::FocusPolicy::StrongFocus',
     'Qt::WheelFocus':   'Qt::FocusPolicy::WheelFocus',
 
-    'Qt::ImhDate':                  'Qt::InputMethodHints::ImhDate',
-    'Qt::ImhDialableCharactersOnly':    'Qt::InputMethodHints::ImhDialableCharactersOnly',
-    'Qt::ImhDigitsOnly':            'Qt::InputMethodHints::ImhDigitsOnly',
-    'Qt::ImhEmailCharactersOnly':   'Qt::InputMethodHints::ImhEmailCharactersOnly',
-    'Qt::ImhExclusiveInputMask':    'Qt::InputMethodHints::ImhExclusiveInputMask',
-    'Qt::ImhFormattedNumbersOnly':  'Qt::InputMethodHints::ImhFormattedNumbersOnly',
-    'Qt::ImhHiddenText':            'Qt::InputMethodHints::ImhHiddenText',
-    'Qt::ImhLatinOnly':             'Qt::InputMethodHints::ImhLatinOnly',
-    'Qt::ImhLowercaseOnly':         'Qt::InputMethodHints::ImhLowercaseOnly',
-    'Qt::ImhMultiLine':             'Qt::InputMethodHints::ImhMultiLine',
-    'Qt::ImhNoAutoUppercase':       'Qt::InputMethodHints::ImhNoAutoUppercase',
-    'Qt::ImhNoEditMenu':            'Qt::InputMethodHints::ImhNoEditMenu',
-    'Qt::ImhNoPredictiveText':      'Qt::InputMethodHints::ImhNoPredictiveText',
-    'Qt::ImhNoTextHandles':         'Qt::InputMethodHints::ImhNoTextHandles',
-    'Qt::ImhNone':                  'Qt::InputMethodHints::ImhNone',
-    'Qt::ImhPreferLatin':           'Qt::InputMethodHints::ImhPreferLatin',
-    'Qt::ImhPreferLowercase':       'Qt::InputMethodHints::ImhPreferLowercase',
-    'Qt::ImhPreferNumbers':         'Qt::InputMethodHints::ImhPreferNumbers',
-    'Qt::ImhPreferUppercase':       'Qt::InputMethodHints::ImhPreferUppercase',
-    'Qt::ImhSensitiveData':         'Qt::InputMethodHints::ImhSensitiveData',
-    'Qt::ImhTime':                  'Qt::InputMethodHints::ImhTime',
-    'Qt::ImhUppercaseOnly':         'Qt::InputMethodHints::ImhUppercaseOnly',
-    'Qt::ImhUrlCharactersOnly':     'Qt::InputMethodHints::ImhUrlCharactersOnly',
+    'Qt::ImhDate':                  'Qt::InputMethodHint::ImhDate',
+    'Qt::ImhDialableCharactersOnly':    'Qt::InputMethodHint::ImhDialableCharactersOnly',
+    'Qt::ImhDigitsOnly':            'Qt::InputMethodHint::ImhDigitsOnly',
+    'Qt::ImhEmailCharactersOnly':   'Qt::InputMethodHint::ImhEmailCharactersOnly',
+    'Qt::ImhExclusiveInputMask':    'Qt::InputMethodHint::ImhExclusiveInputMask',
+    'Qt::ImhFormattedNumbersOnly':  'Qt::InputMethodHint::ImhFormattedNumbersOnly',
+    'Qt::ImhHiddenText':            'Qt::InputMethodHint::ImhHiddenText',
+    'Qt::ImhLatinOnly':             'Qt::InputMethodHint::ImhLatinOnly',
+    'Qt::ImhLowercaseOnly':         'Qt::InputMethodHint::ImhLowercaseOnly',
+    'Qt::ImhMultiLine':             'Qt::InputMethodHint::ImhMultiLine',
+    'Qt::ImhNoAutoUppercase':       'Qt::InputMethodHint::ImhNoAutoUppercase',
+    'Qt::ImhNoEditMenu':            'Qt::InputMethodHint::ImhNoEditMenu',
+    'Qt::ImhNoPredictiveText':      'Qt::InputMethodHint::ImhNoPredictiveText',
+    'Qt::ImhNoTextHandles':         'Qt::InputMethodHint::ImhNoTextHandles',
+    'Qt::ImhNone':                  'Qt::InputMethodHint::ImhNone',
+    'Qt::ImhPreferLatin':           'Qt::InputMethodHint::ImhPreferLatin',
+    'Qt::ImhPreferLowercase':       'Qt::InputMethodHint::ImhPreferLowercase',
+    'Qt::ImhPreferNumbers':         'Qt::InputMethodHint::ImhPreferNumbers',
+    'Qt::ImhPreferUppercase':       'Qt::InputMethodHint::ImhPreferUppercase',
+    'Qt::ImhSensitiveData':         'Qt::InputMethodHint::ImhSensitiveData',
+    'Qt::ImhTime':                  'Qt::InputMethodHint::ImhTime',
+    'Qt::ImhUppercaseOnly':         'Qt::InputMethodHint::ImhUppercaseOnly',
+    'Qt::ImhUrlCharactersOnly':     'Qt::InputMethodHint::ImhUrlCharactersOnly',
 
-    'Qt::ItemIsAutoTristate':   'Qt::ItemFlags::ItemIsAutoTristate',
-    'Qt::ItemIsDragEnabled':    'Qt::ItemFlags::ItemIsDragEnabled',
-    'Qt::ItemIsDropEnabled':    'Qt::ItemFlags::ItemIsDropEnabled',
-    'Qt::ItemIsEditable':       'Qt::ItemFlags::ItemIsEditable',
-    'Qt::ItemIsEnabled':        'Qt::ItemFlags::ItemIsEnabled',
-    'Qt::ItemIsSelectable':     'Qt::ItemFlags::ItemIsSelectable',
-    'Qt::ItemIsUserCheckable':  'Qt::ItemFlags::ItemIsUserCheckable',
-    'Qt::ItemIsUserTristate':   'Qt::ItemFlags::ItemIsUserTristate',
-    'Qt::ItemNeverHasChildren': 'Qt::ItemFlags::ItemNeverHasChildren',
-    'Qt::NoItemFlags':          'Qt::ItemFlags::NoItemFlags',
+    'Qt::ItemIsAutoTristate':   'Qt::ItemFlag::ItemIsAutoTristate',
+    'Qt::ItemIsDragEnabled':    'Qt::ItemFlag::ItemIsDragEnabled',
+    'Qt::ItemIsDropEnabled':    'Qt::ItemFlag::ItemIsDropEnabled',
+    'Qt::ItemIsEditable':       'Qt::ItemFlag::ItemIsEditable',
+    'Qt::ItemIsEnabled':        'Qt::ItemFlag::ItemIsEnabled',
+    'Qt::ItemIsSelectable':     'Qt::ItemFlag::ItemIsSelectable',
+    'Qt::ItemIsUserCheckable':  'Qt::ItemFlag::ItemIsUserCheckable',
+    'Qt::ItemIsUserTristate':   'Qt::ItemFlag::ItemIsUserTristate',
+    'Qt::ItemNeverHasChildren': 'Qt::ItemFlag::ItemNeverHasChildren',
+    'Qt::NoItemFlags':          'Qt::ItemFlag::NoItemFlags',
 
     'Qt::ContainsItemBoundingRect':     'Qt::ItemSelectionMode::ContainsItemBoundingRect',
     'Qt::ContainsItemShape':            'Qt::ItemSelectionMode::ContainsItemShape',
@@ -128,8 +128,8 @@ EnumMap = {
     'Qt::LeftToRight':          'Qt::LayoutDirection::LeftToRight',
     'Qt::RightToLeft':          'Qt::LayoutDirection::RightToLeft',
 
-    'Qt::Horizontal':   'Qt::Orientations::Horizontal',
-    'Qt::Vertical':     'Qt::Orientations::Vertical',
+    'Qt::Horizontal':   'Qt::Orientation::Horizontal',
+    'Qt::Vertical':     'Qt::Orientation::Vertical',
 
     'Qt::CustomDashLine':   'Qt::PenStyle::CustomDashLine',
     'Qt::DashDotDotLine':   'Qt::PenStyle::DashDotDotLine',
@@ -148,14 +148,14 @@ EnumMap = {
     'Qt::ElideMiddle':  'Qt::TextElideMode::ElideMiddle',
     'Qt::ElideNone':    'Qt::TextElideMode::ElideNone',
 
-    'Qt::NoTextInteraction':            'Qt::TextInteractionFlags::NoTextInteraction',
-    'Qt::TextSelectableByMouse':        'Qt::TextInteractionFlags::TextSelectableByMouse',
-    'Qt::TextSelectableByKeyboard':     'Qt::TextInteractionFlags::TextSelectableByKeyboard',
-    'Qt::LinksAccessibleByMouse':       'Qt::TextInteractionFlags::LinksAccessibleByMouse',
-    'Qt::LinksAccessibleByKeyboard':    'Qt::TextInteractionFlags::LinksAccessibleByKeyboard',
-    'Qt::TextEditable':                 'Qt::TextInteractionFlags::TextEditable',
-    'Qt::TextEditorInteraction':        'Qt::TextInteractionFlags::TextEditorInteraction',
-    'Qt::TextBrowserInteraction':       'Qt::TextInteractionFlags::TextBrowserInteraction',
+    'Qt::NoTextInteraction':            'Qt::TextInteractionFlag::NoTextInteraction',
+    'Qt::TextSelectableByMouse':        'Qt::TextInteractionFlag::TextSelectableByMouse',
+    'Qt::TextSelectableByKeyboard':     'Qt::TextInteractionFlag::TextSelectableByKeyboard',
+    'Qt::LinksAccessibleByMouse':       'Qt::TextInteractionFlag::LinksAccessibleByMouse',
+    'Qt::LinksAccessibleByKeyboard':    'Qt::TextInteractionFlag::LinksAccessibleByKeyboard',
+    'Qt::TextEditable':                 'Qt::TextInteractionFlag::TextEditable',
+    'Qt::TextEditorInteraction':        'Qt::TextInteractionFlag::TextEditorInteraction',
+    'Qt::TextBrowserInteraction':       'Qt::TextInteractionFlag::TextBrowserInteraction',
 
     'Qt::AutoText':     'Qt::TextFormat::AutoText',
     'Qt::MarkdownText': 'Qt::TextFormat::MarkdownText',
@@ -167,12 +167,12 @@ EnumMap = {
     'Qt::TimeZone':         'Qt::TimeSpec::TimeZone',
     'Qt::UTC':              'Qt::TimeSpec::UTC',
 
-    'Qt::LeftToolBarArea':      'Qt::ToolBarAreas::LeftToolBarArea',
-    'Qt::RightToolBarArea':     'Qt::ToolBarAreas::RightToolBarArea',
-    'Qt::TopToolBarArea':       'Qt::ToolBarAreas::TopToolBarArea',
-    'Qt::BottomToolBarArea':    'Qt::ToolBarAreas::BottomToolBarArea',
-    'Qt::AllToolBarAreas':      'Qt::ToolBarAreas::AllToolBarAreas',
-    'Qt::NoToolBarArea':        'Qt::ToolBarAreas::NoToolBarArea',
+    'Qt::LeftToolBarArea':      'Qt::ToolBarArea::LeftToolBarArea',
+    'Qt::RightToolBarArea':     'Qt::ToolBarArea::RightToolBarArea',
+    'Qt::TopToolBarArea':       'Qt::ToolBarArea::TopToolBarArea',
+    'Qt::BottomToolBarArea':    'Qt::ToolBarArea::BottomToolBarArea',
+    'Qt::AllToolBarAreas':      'Qt::ToolBarArea::AllToolBarAreas',
+    'Qt::NoToolBarArea':        'Qt::ToolBarArea::NoToolBarArea',
 
     'Qt::ToolButtonFollowStyle':    'Qt::ToolButtonStyle::ToolButtonFollowStyle',
     'Qt::ToolButtonIconOnly':       'Qt::ToolButtonStyle::ToolButtonIconOnly',
@@ -190,13 +190,13 @@ EnumMap = {
     'QAbstractItemView::DragDrop':      'QAbstractItemView::DragDropMode::DragDrop',
     'QAbstractItemView::InternalMove':  'QAbstractItemView::DragDropMode::InternalMove',
 
-    'QAbstractItemView::NoEditTriggers':    'QAbstractItemView::EditTriggers::NoEditTriggers',
-    'QAbstractItemView::CurrentChanged':    'QAbstractItemView::EditTriggers::CurrentChanged',
-    'QAbstractItemView::DoubleClicked':     'QAbstractItemView::EditTriggers::DoubleClicked',
-    'QAbstractItemView::SelectedClicked':   'QAbstractItemView::EditTriggers::SelectedClicked',
-    'QAbstractItemView::EditKeyPressed':    'QAbstractItemView::EditTriggers::EditKeyPressed',
-    'QAbstractItemView::AnyKeyPressed':     'QAbstractItemView::EditTriggers::AnyKeyPressed',
-    'QAbstractItemView::AllEditTriggers':   'QAbstractItemView::EditTriggers::AllEditTriggers',
+    'QAbstractItemView::NoEditTriggers':    'QAbstractItemView::EditTrigger::NoEditTriggers',
+    'QAbstractItemView::CurrentChanged':    'QAbstractItemView::EditTrigger::CurrentChanged',
+    'QAbstractItemView::DoubleClicked':     'QAbstractItemView::EditTrigger::DoubleClicked',
+    'QAbstractItemView::SelectedClicked':   'QAbstractItemView::EditTrigger::SelectedClicked',
+    'QAbstractItemView::EditKeyPressed':    'QAbstractItemView::EditTrigger::EditKeyPressed',
+    'QAbstractItemView::AnyKeyPressed':     'QAbstractItemView::EditTrigger::AnyKeyPressed',
+    'QAbstractItemView::AllEditTriggers':   'QAbstractItemView::EditTrigger::AllEditTriggers',
 
     'QAbstractItemView::ScrollPerItem':     'QAbstractItemView::ScrollMode::ScrollPerItem',
     'QAbstractItemView::ScrollPerPixel':    'QAbstractItemView::ScrollMode::ScrollPerPixel',
@@ -225,6 +225,14 @@ EnumMap = {
     'QAbstractSpinBox::AdaptiveDecimalStepType':    'QAbstractSpinBox::StepType::AdaptiveDecimalStepType',
     'QAbstractSpinBox::DefaultStepType':            'QAbstractSpinBox::StepType::DefaultStepType',
 
+    'QAction::NoRole':                  'QAction::MenuRole::NoRole',
+    'QAction::TextHeuristicRole':       'QAction::MenuRole::TextHeuristicRole',
+    'QAction::ApplicationSpecificRole': 'QAction::MenuRole::ApplicationSpecificRole',
+    'QAction::AboutQtRole':             'QAction::MenuRole::AboutQtRole',
+    'QAction::AboutRole':               'QAction::MenuRole::AboutRole',
+    'QAction::PreferencesRole':         'QAction::MenuRole::PreferencesRole',
+    'QAction::QuitRole':                'QAction::MenuRole::QuitRole',
+
     'QCalendarWidget::LongDayNames':            'QCalendarWidget::HorizontalHeaderFormat::LongDayNames',
     'QCalendarWidget::NoHorizontalHeader':      'QCalendarWidget::HorizontalHeaderFormat::NoHorizontalHeader',
     'QCalendarWidget::ShortDayNames':           'QCalendarWidget::HorizontalHeaderFormat::ShortDayNames',
@@ -248,47 +256,47 @@ EnumMap = {
     'QComboBox::AdjustToContentsOnFirstShow':           'QComboBox::SizeAdjustPolicy::AdjustToContentsOnFirstShow',
     'QComboBox::AdjustToMinimumContentsLengthWithIcon': 'QComboBox::SizeAdjustPolicy::AdjustToMinimumContentsLengthWithIcon',
 
-    'QDateTimeEdit::NoSection':             'QDateTimeEdit::Sections::NoSection',
-    'QDateTimeEdit::AmPmSection':           'QDateTimeEdit::Sections::AmPmSection',
-    'QDateTimeEdit::MSecSection':           'QDateTimeEdit::Sections::MSecSection',
-    'QDateTimeEdit::SecondSection':         'QDateTimeEdit::Sections::SecondSection',
-    'QDateTimeEdit::MinuteSection':         'QDateTimeEdit::Sections::MinuteSection',
-    'QDateTimeEdit::HourSection':           'QDateTimeEdit::Sections::HourSection',
-    'QDateTimeEdit::DaySection':            'QDateTimeEdit::Sections::DaySection',
-    'QDateTimeEdit::MonthSection':          'QDateTimeEdit::Sections::MonthSection',
-    'QDateTimeEdit::YearSection':           'QDateTimeEdit::Sections::YearSection',
+    'QDateTimeEdit::NoSection':             'QDateTimeEdit::Section::NoSection',
+    'QDateTimeEdit::AmPmSection':           'QDateTimeEdit::Section::AmPmSection',
+    'QDateTimeEdit::MSecSection':           'QDateTimeEdit::Section::MSecSection',
+    'QDateTimeEdit::SecondSection':         'QDateTimeEdit::Section::SecondSection',
+    'QDateTimeEdit::MinuteSection':         'QDateTimeEdit::Section::MinuteSection',
+    'QDateTimeEdit::HourSection':           'QDateTimeEdit::Section::HourSection',
+    'QDateTimeEdit::DaySection':            'QDateTimeEdit::Section::DaySection',
+    'QDateTimeEdit::MonthSection':          'QDateTimeEdit::Section::MonthSection',
+    'QDateTimeEdit::YearSection':           'QDateTimeEdit::Section::YearSection',
 
-    'QDialogButtonBox::NoButton':           'QDialogButtonBox::StandardButtons::NoButton',
-    'QDialogButtonBox::Ok':                 'QDialogButtonBox::StandardButtons::Ok',
-    'QDialogButtonBox::Save':               'QDialogButtonBox::StandardButtons::Save',
-    'QDialogButtonBox::SaveAll':            'QDialogButtonBox::StandardButtons::SaveAll',
-    'QDialogButtonBox::Open':               'QDialogButtonBox::StandardButtons::Open',
-    'QDialogButtonBox::Yes':                'QDialogButtonBox::StandardButtons::Yes',
-    'QDialogButtonBox::YesToAll':           'QDialogButtonBox::StandardButtons::YesToAll',
-    'QDialogButtonBox::No':                 'QDialogButtonBox::StandardButtons::No',
-    'QDialogButtonBox::NoToAll':            'QDialogButtonBox::StandardButtons::NoToAll',
-    'QDialogButtonBox::Abort':              'QDialogButtonBox::StandardButtons::Abort',
-    'QDialogButtonBox::Retry':              'QDialogButtonBox::StandardButtons::Retry',
-    'QDialogButtonBox::Ignore':             'QDialogButtonBox::StandardButtons::Ignore',
-    'QDialogButtonBox::Close':              'QDialogButtonBox::StandardButtons::Close',
-    'QDialogButtonBox::Cancel':             'QDialogButtonBox::StandardButtons::Cancel',
-    'QDialogButtonBox::Discard':            'QDialogButtonBox::StandardButtons::Discard',
-    'QDialogButtonBox::Help':               'QDialogButtonBox::StandardButtons::Help',
-    'QDialogButtonBox::Apply':              'QDialogButtonBox::StandardButtons::Apply',
-    'QDialogButtonBox::Reset':              'QDialogButtonBox::StandardButtons::Reset',
-    'QDialogButtonBox::RestoreDefaults':    'QDialogButtonBox::StandardButtons::RestoreDefaults',
+    'QDialogButtonBox::NoButton':           'QDialogButtonBox::StandardButton::NoButton',
+    'QDialogButtonBox::Ok':                 'QDialogButtonBox::StandardButton::Ok',
+    'QDialogButtonBox::Save':               'QDialogButtonBox::StandardButton::Save',
+    'QDialogButtonBox::SaveAll':            'QDialogButtonBox::StandardButton::SaveAll',
+    'QDialogButtonBox::Open':               'QDialogButtonBox::StandardButton::Open',
+    'QDialogButtonBox::Yes':                'QDialogButtonBox::StandardButton::Yes',
+    'QDialogButtonBox::YesToAll':           'QDialogButtonBox::StandardButton::YesToAll',
+    'QDialogButtonBox::No':                 'QDialogButtonBox::StandardButton::No',
+    'QDialogButtonBox::NoToAll':            'QDialogButtonBox::StandardButton::NoToAll',
+    'QDialogButtonBox::Abort':              'QDialogButtonBox::StandardButton::Abort',
+    'QDialogButtonBox::Retry':              'QDialogButtonBox::StandardButton::Retry',
+    'QDialogButtonBox::Ignore':             'QDialogButtonBox::StandardButton::Ignore',
+    'QDialogButtonBox::Close':              'QDialogButtonBox::StandardButton::Close',
+    'QDialogButtonBox::Cancel':             'QDialogButtonBox::StandardButton::Cancel',
+    'QDialogButtonBox::Discard':            'QDialogButtonBox::StandardButton::Discard',
+    'QDialogButtonBox::Help':               'QDialogButtonBox::StandardButton::Help',
+    'QDialogButtonBox::Apply':              'QDialogButtonBox::StandardButton::Apply',
+    'QDialogButtonBox::Reset':              'QDialogButtonBox::StandardButton::Reset',
+    'QDialogButtonBox::RestoreDefaults':    'QDialogButtonBox::StandardButton::RestoreDefaults',
 
-    'QDockWidget::DockWidgetClosable':          'QDockWidget::DockWidgetFeatures::DockWidgetClosable',
-    'QDockWidget::DockWidgetFloatable':         'QDockWidget::DockWidgetFeatures::DockWidgetFloatable',
-    'QDockWidget::DockWidgetMovable':           'QDockWidget::DockWidgetFeatures::DockWidgetMovable',
-    'QDockWidget::DockWidgetVerticalTitleBar':  'QDockWidget::DockWidgetFeatures::DockWidgetVerticalTitleBar',
-    'QDockWidget::NoDockWidgetFeatures':        'QDockWidget::DockWidgetFeatures::NoDockWidgetFeatures',
+    'QDockWidget::DockWidgetClosable':          'QDockWidget::DockWidgetFeature::DockWidgetClosable',
+    'QDockWidget::DockWidgetFloatable':         'QDockWidget::DockWidgetFeature::DockWidgetFloatable',
+    'QDockWidget::DockWidgetMovable':           'QDockWidget::DockWidgetFeature::DockWidgetMovable',
+    'QDockWidget::DockWidgetVerticalTitleBar':  'QDockWidget::DockWidgetFeature::DockWidgetVerticalTitleBar',
+    'QDockWidget::NoDockWidgetFeatures':        'QDockWidget::DockWidgetFeature::NoDockWidgetFeatures',
 
-    'QFontComboBox::AllFonts':          'QFontComboBox::FontFilters::AllFonts',
-    'QFontComboBox::MonospacedFonts':   'QFontComboBox::FontFilters::MonospacedFonts',
-    'QFontComboBox::NonScalableFonts':  'QFontComboBox::FontFilters::NonScalableFonts',
-    'QFontComboBox::ProportionalFonts': 'QFontComboBox::FontFilters::ProportionalFonts',
-    'QFontComboBox::ScalableFonts':     'QFontComboBox::FontFilters::ScalableFonts',
+    'QFontComboBox::AllFonts':          'QFontComboBox::FontFilter::AllFonts',
+    'QFontComboBox::MonospacedFonts':   'QFontComboBox::FontFilter::MonospacedFonts',
+    'QFontComboBox::NonScalableFonts':  'QFontComboBox::FontFilter::NonScalableFonts',
+    'QFontComboBox::ProportionalFonts': 'QFontComboBox::FontFilter::ProportionalFonts',
+    'QFontComboBox::ScalableFonts':     'QFontComboBox::FontFilter::ScalableFonts',
 
     'QFontDatabase::Any':                   'QFontDatabase::WritingSystem::Any',
     'QFontDatabase::Latin':                 'QFontDatabase::WritingSystem::Latin',
@@ -354,6 +362,13 @@ EnumMap = {
     'QGraphicsView::NoViewportUpdate':              'QGraphicsView::ViewportUpdateMode::NoViewportUpdate',
     'QGraphicsView::SmartViewportUpdate':           'QGraphicsView::ViewportUpdateMode::SmartViewportUpdate',
 
+    'QLayout::SetDefaultConstraint':    'QLayout::SizeConstraint::SetDefaultConstraint',
+    'QLayout::SetFixedSize':            'QLayout::SizeConstraint::SetFixedSize',
+    'QLayout::SetMaximumSize':          'QLayout::SizeConstraint::SetMaximumSize',
+    'QLayout::SetMinAndMaxSize':        'QLayout::SizeConstraint::SetMinAndMaxSize',
+    'QLayout::SetMinimumSize':          'QLayout::SizeConstraint::SetMinimumSize',
+    'QLayout::SetNoConstraint':         'QLayout::SizeConstraint::SetNoConstraint',
+
     'QLCDNumber::Bin':  'QLCDNumber::Mode::Bin',
     'QLCDNumber::Dec':  'QLCDNumber::Mode::Dec',
     'QLCDNumber::Hex':  'QLCDNumber::Mode::Hex',
@@ -391,10 +406,10 @@ EnumMap = {
     'QMdiArea::CreationOrder':          'QMdiArea::WindowOrder::CreationOrder',
     'QMdiArea::StackingOrder':          'QMdiArea::WindowOrder::StackingOrder',
 
-    'QPainter::Antialiasing':           'QPainter::RenderHints::Antialiasing',
-    'QPainter::LosslessImageRendering': 'QPainter::RenderHints::LosslessImageRendering',
-    'QPainter::SmoothPixmapTransform':  'QPainter::RenderHints::SmoothPixmapTransform',
-    'QPainter::TextAntialiasing':       'QPainter::RenderHints::TextAntialiasing',
+    'QPainter::Antialiasing':           'QPainter::RenderHint::Antialiasing',
+    'QPainter::LosslessImageRendering': 'QPainter::RenderHint::LosslessImageRendering',
+    'QPainter::SmoothPixmapTransform':  'QPainter::RenderHint::SmoothPixmapTransform',
+    'QPainter::TextAntialiasing':       'QPainter::RenderHint::TextAntialiasing',
 
     'QPlainTextEdit::NoWrap':       'QPlainTextEdit::LineWrapMode::NoWrap',
     'QPlainTextEdit::WidgetWidth':  'QPlainTextEdit::LineWrapMode::WidgetWidth',
@@ -428,9 +443,9 @@ EnumMap = {
     'QTabWidget::Rounded':      'QTabWidget::TabShape::Rounded',
     'QTabWidget::Triangular':   'QTabWidget::TabShape::Triangular',
 
-    'QTextEdit::AutoAll':           'QTextEdit::AutoFormatting::AutoAll',
-    'QTextEdit::AutoBulletList':    'QTextEdit::AutoFormatting::AutoBulletList',
-    'QTextEdit::AutoNone':          'QTextEdit::AutoFormatting::AutoNone',
+    'QTextEdit::AutoAll':           'QTextEdit::AutoFormattingFlag::AutoAll',
+    'QTextEdit::AutoBulletList':    'QTextEdit::AutoFormattingFlag::AutoBulletList',
+    'QTextEdit::AutoNone':          'QTextEdit::AutoFormattingFlag::AutoNone',
 
     'QTextEdit::FixedColumnWidth':  'QTextEdit::LineWrapMode::FixedColumnWidth',
     'QTextEdit::FixedPixelWidth':   'QTextEdit::LineWrapMode::FixedPixelWidth',
@@ -441,23 +456,23 @@ EnumMap = {
     'QToolButton::InstantPopup':    'QToolButton::ToolButtonPopupMode::InstantPopup',
     'QToolButton::MenuButtonPopup': 'QToolButton::ToolButtonPopupMode::MenuButtonPopup',
 
-    'QWizard::CancelButtonOnLeft':              'QWizard::WizardOptions::CancelButtonOnLeft',
-    'QWizard::DisabledBackButtonOnLastPage':    'QWizard::WizardOptions::DisabledBackButtonOnLastPage',
-    'QWizard::ExtendedWatermarkPixmap':         'QWizard::WizardOptions::ExtendedWatermarkPixmap',
-    'QWizard::HaveCustomButton1':               'QWizard::WizardOptions::HaveCustomButton1',
-    'QWizard::HaveCustomButton2':               'QWizard::WizardOptions::HaveCustomButton2',
-    'QWizard::HaveCustomButton3':               'QWizard::WizardOptions::HaveCustomButton3',
-    'QWizard::HaveFinishButtonOnEarlyPages':    'QWizard::WizardOptions::HaveFinishButtonOnEarlyPages',
-    'QWizard::HaveHelpButton':                  'QWizard::WizardOptions::HaveHelpButton',
-    'QWizard::HaveNextButtonOnLastPage':        'QWizard::WizardOptions::HaveNextButtonOnLastPage',
-    'QWizard::HelpButtonOnRight':               'QWizard::WizardOptions::HelpButtonOnRight',
-    'QWizard::IgnoreSubTitles':                 'QWizard::WizardOptions::IgnoreSubTitles',
-    'QWizard::IndependentPages':                'QWizard::WizardOptions::IndependentPages',
-    'QWizard::NoBackButtonOnLastPage':          'QWizard::WizardOptions::NoBackButtonOnLastPage',
-    'QWizard::NoBackButtonOnStartPage':         'QWizard::WizardOptions::NoBackButtonOnStartPage',
-    'QWizard::NoCancelButton':                  'QWizard::WizardOptions::NoCancelButton',
-    'QWizard::NoCancelButtonOnLastPage':        'QWizard::WizardOptions::NoCancelButtonOnLastPage',
-    'QWizard::NoDefaultButton':                 'QWizard::WizardOptions::NoDefaultButton',
+    'QWizard::CancelButtonOnLeft':              'QWizard::WizardOption::CancelButtonOnLeft',
+    'QWizard::DisabledBackButtonOnLastPage':    'QWizard::WizardOption::DisabledBackButtonOnLastPage',
+    'QWizard::ExtendedWatermarkPixmap':         'QWizard::WizardOption::ExtendedWatermarkPixmap',
+    'QWizard::HaveCustomButton1':               'QWizard::WizardOption::HaveCustomButton1',
+    'QWizard::HaveCustomButton2':               'QWizard::WizardOption::HaveCustomButton2',
+    'QWizard::HaveCustomButton3':               'QWizard::WizardOption::HaveCustomButton3',
+    'QWizard::HaveFinishButtonOnEarlyPages':    'QWizard::WizardOption::HaveFinishButtonOnEarlyPages',
+    'QWizard::HaveHelpButton':                  'QWizard::WizardOption::HaveHelpButton',
+    'QWizard::HaveNextButtonOnLastPage':        'QWizard::WizardOption::HaveNextButtonOnLastPage',
+    'QWizard::HelpButtonOnRight':               'QWizard::WizardOption::HelpButtonOnRight',
+    'QWizard::IgnoreSubTitles':                 'QWizard::WizardOption::IgnoreSubTitles',
+    'QWizard::IndependentPages':                'QWizard::WizardOption::IndependentPages',
+    'QWizard::NoBackButtonOnLastPage':          'QWizard::WizardOption::NoBackButtonOnLastPage',
+    'QWizard::NoBackButtonOnStartPage':         'QWizard::WizardOption::NoBackButtonOnStartPage',
+    'QWizard::NoCancelButton':                  'QWizard::WizardOption::NoCancelButton',
+    'QWizard::NoCancelButtonOnLastPage':        'QWizard::WizardOption::NoCancelButtonOnLastPage',
+    'QWizard::NoDefaultButton':                 'QWizard::WizardOption::NoDefaultButton',
 
     'QWizard::AeroStyle':       'QWizard::WizardStyle::AeroStyle',
     'QWizard::ClassicStyle':    'QWizard::WizardStyle::ClassicStyle',
